using System;
using System.Drawing;
using MonoTouch.Foundation;
using MonoTouch.UIKit;
using Infragistics;
using System.Collections.Generic;
namespace AddingDataToChart_Xamarin
{
	public partial class AddingDataToChart_XamarinViewController : UIViewController
	{
		IGChartView _chart;
		IGCategorySeriesDataSourceHelper _helper;
		List<MyDataObject> _dataArray;
		NSTimer _timer;
		NSObject[] _convertedData;


		static bool UserInterfaceIdiomIsPhone {
			get { return UIDevice.CurrentDevice.UserInterfaceIdiom == UIUserInterfaceIdiom.Phone; }
		}

		public AddingDataToChart_XamarinViewController ()
			: base (UserInterfaceIdiomIsPhone ? "AddingDataToChart_XamarinViewController_iPhone" : "AddingDataToChart_XamarinViewController_iPad", null)
		{
		}

		public override void DidReceiveMemoryWarning ()
		{
			// Releases the view if it doesn't have a superview.
			base.DidReceiveMemoryWarning ();
			
			// Release any cached data, images, etc that aren't in use.
		}

		public override void ViewDidLoad ()
		{
			base.ViewDidLoad ();
			
			// Perform any additional setup after loading the view, typically from a nib.
		
			// create the chart
			_chart = new IGChartView ();

			_chart.Frame = RectangleF.Inflate (new RectangleF (0, 0, this.View.Frame.Size.Width, this.View.Frame.Size.Height), -20, -20);

			// make some data

			_dataArray = new List<MyDataObject> ();
			for (int i = 0; i< 21; i++) {
				_dataArray.Add (createDataObject ());
			}
			_convertedData = _dataArray.ToArray ();
			// create data source helper
			_helper = new IGCategorySeriesDataSourceHelper (_convertedData, "value");

			// add series
			IGLineSeries lineSeries =(IGLineSeries)	_chart.AddSeries (new MonoTouch.ObjCRuntime.Class ("IGLineSeries"), @"series1", _helper, @"xAxis", @"yAxis");

			// just ensures that the data points we expect to show will be in range of rendering.
			lineSeries.YAxis.Minimum = 0;
			lineSeries.YAxis.Maximum = 10;

			// turning off horizontal labels as they won't mean much in this sample.
			lineSeries.XAxis.LabelsVisible = false;

			// create the axis and series objects
			this.View.AddSubview (_chart);
		}

		public override void ViewWillAppear (bool animated)
		{
			base.ViewWillAppear (animated);
			_timer = NSTimer.CreateRepeatingScheduledTimer (1, ()=>this.onTick(_timer));
		}

		public override void ViewWillDisappear (bool animated)
		{
			base.ViewWillDisappear (animated);
			_timer = null;
		}


		public void onTick(NSTimer timer)
		{
			// On the Tick, make a new object in the bounds.  
			MyDataObject newOb	= this.createDataObject ();

			// Since we only want to show the last twenty data points, remove the first if we have hit the threshold
			if (_dataArray.Count >= 21) {
				// remove the data point and tell the chart that the point of data has been removed.
				_dataArray.RemoveAt (0);
				_chart.RemoveItem (0, _helper);
			}

			// now add in our new data point and tell the chart that a new point has been added.
			_dataArray.Add (newOb);
			_convertedData = _dataArray.ToArray ();
			_helper.Data = _convertedData;
			_chart.InsertItem (_convertedData.Length - 1, _helper);
		}

		MyDataObject createDataObject()
		{
			MyDataObject obj = new MyDataObject ();
			obj.Value = new Random ().Next() % 10;
			return obj;
		}
	}

	public class MyDataObject:NSObject
	{
		[Export("value")]
		public int Value {get;set;}
	}
}

