//
//  ViewController.m
//  AddingDataToDataSource
//
//  Created by Darrell Kress on 11/15/13.
//  Copyright (c) 2013 DEK. All rights reserved.
//

#import "ViewController.h"

@interface MyDataObject : NSObject
@property (nonatomic) NSInteger value;
@property (retain) NSString* name;
@end
@implementation MyDataObject
@end

@interface ViewController ()
@end

@implementation ViewController

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
    
    // Create the Chart
    CGRect chartSize = CGRectMake(0, 0 , self.view.frame.size.width  , self.view.frame.size.height);
    
    _chart = [[IGChartView alloc]initWithFrame:CGRectInset(chartSize, 20, 20)];
    
    _chart.autoresizingMask = UIViewAutoresizingFlexibleHeight | UIViewAutoresizingFlexibleWidth;

    // Make some data
    _dataArray = [[NSMutableArray alloc]init];
    for (NSInteger i = 0 ; i < 21    ; i++)
    {
        [_dataArray addObject:[self createDataObject]];
    }
    
    // Create the data source helper for the Line series
    _helper = [[IGCategorySeriesDataSourceHelper alloc]initWithData:_dataArray andValuePath:@"value"];
    
    // make the line series
    IGLineSeries* lineSeries = (IGLineSeries*)[_chart addSeriesForType:[IGLineSeries class] usingKey:@"series1" withDataSource:_helper firstAxisKey:@"xAxis" secondAxisKey:@"yAxis"];
    
    // just ensures that the data points we expect to show will be in range of rendering.
    lineSeries.yAxis.minimum = 0;
    lineSeries.yAxis.maximum = 10;
    
    // turning off horizontal labels as they won't mean much in this sample.
    lineSeries.xAxis.labelsVisible = NO;
    
    // add chart to view
    [self.view addSubview:_chart];
  
}

-(void)viewWillAppear:(BOOL)animated
{
    _timer = [NSTimer scheduledTimerWithTimeInterval:1 target:self selector:@selector(onTick:) userInfo:nil repeats:YES ];
}
-(void)viewWillDisappear:(BOOL)animated
{
    _timer = nil;
}
// a simple helper method that makes data objects
-(MyDataObject*)createDataObject
{
    MyDataObject* newObject = [[MyDataObject alloc]init];
    newObject.value = rand() % 10;
    return newObject;
}
-(void)onTick:(NSTimer*)timer
{
    // Since we only want to show the last twenty data points, remove the first if we have hit the threshold
    if (_dataArray.count >= 21) {
        // remove the data point and tell the chart that the point of data has been removed.
        [_dataArray removeObjectAtIndex:0];
        [_chart removeItemAtIndex:0 withSource:_helper];
    }
    
    // adds a new data object to our underlying data collection
    [_dataArray addObject:[self createDataObject]];
    
    // tells the chart to put a new point into the view
    [_chart insertItemAtIndex:(_dataArray.count-1) withSource:_helper];
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

@end
